@@ -42,6 +42,11 @@ except ImportError:
 finally:
     from reuse import extract, report
     from reuse._util import setup_logging
+    from reuse.comment import (
+        EmptyCommentStyle,
+        UncommentableCommentStyle,
+        _all_style_classes,
+    )
     from reuse.global_licensing import ReuseDep5
     from reuse.lint import format_lines, format_lines_subset
     from reuse.vcs import GIT_EXE, HG_EXE, JUJUTSU_EXE, PIJUL_EXE
@@ -190,13 +195,21 @@ def multiprocessing(request, monkeypatch) -> Generator[bool, None, None]:
     yield request.param
 
 
-@pytest.fixture(params=["magic", "charset_normalizer", "chardet"])
+@pytest.fixture(
+    params=["python-magic", "file-magic", "charset_normalizer", "chardet"]
+)
 def encoding_module(request, monkeypatch) -> Generator[bool, None, None]:
     """Run the test with or without libmagic."""
+    is_magic = "magic" in request.param
+    if is_magic and not is_posix:
+        pytest.skip("Windows not supported")
     try:
-        if request.param == "magic" and not is_posix:
-            pytest.skip("Windows not supported")
-        module = importlib.import_module(request.param)
+        module = importlib.import_module(
+            request.param if not is_magic else "magic"
+        )
+        # pylint: disable=protected-access
+        if is_magic and extract._detect_magic(module) != request.param:
+            pytest.skip(f"'magic' does not import as {request.param}")
         monkeypatch.setattr("reuse.extract._ENCODING_MODULE", module)
         yield request.param
     except ImportError:
@@ -659,6 +672,41 @@ def mock_date_today(monkeypatch):
     monkeypatch.setattr(datetime, "date", date)
 
 
+def _filtered_styles(predicate):
+    return [
+        Style
+        for Style in _all_style_classes()
+        if Style not in (EmptyCommentStyle, UncommentableCommentStyle)
+        and predicate(Style)
+    ]
+
+
+@pytest.fixture(params=_filtered_styles(lambda s: True))
+def comment_style(request):
+    """Yield all CommentStyle classes, excluding EmptyCommentStyle and
+    UncommentableCommentStyle.
+    """
+    yield request.param
+
+
+@pytest.fixture(params=_filtered_styles(lambda s: s.can_handle_single()))
+def single_style(request):
+    """Yield all CommentStyle classes that support single-line comments."""
+    yield request.param
+
+
+@pytest.fixture(params=_filtered_styles(lambda s: s.can_handle_multi()))
+def multi_style(request):
+    """Yield all CommentStyle classes that support multi-line comments."""
+    yield request.param
+
+
+@pytest.fixture(params=_filtered_styles(lambda s: s.SHEBANGS))
+def shebang_style(request):
+    """Yield all CommentStyle classes that support shebangs."""
+    yield request.param
+
+
 @pytest.fixture(
     params=[[], ["John Doe"], ["John Doe", "Alice Doe"]],
     ids=["None", "John", "John and Alice"],
